<?php

/**
 * @file
 * Data definitions used by the importexportapi module to import or export
 * proteus nodes.
 */

/**
 * Implements hook_def().
 */
function proteus_def() {
  $defs = array();

  $type = 'proteusquiz';
  $def = importexportapi_node_get_def($type);
  $def['#title'] = 'Proteus Quiz';

  $def['#xml_plural'] = $def['#csv_plural'] = 'proteusquiz-nodes';
  $def['revisions']['#csv_plural'] = 'proteusquiz-revisions';

  $def['type']['#db_filter'] = array(
    'values' => array($type)
  );

  $def['proteusquiz_nid'] = array(
    '#type' => 'int',
    '#title' => t('Node ID'),
    '#reference_entity' => $type,
    '#reference_field' => array('nid'),
    '#db_table' => 'proteus_quiz',
    '#db_field_unaliased' => 'nid',
    '#key_component' => TRUE,
    '#csv_hidden' => TRUE,
  );
  $def['proteusquiz_vid'] = array(
    '#type' => 'int',
    '#title' => t('Version ID'),
    '#reference_entity' => $type,
    '#reference_field' => array('vid'),
    '#db_table' => 'proteus_quiz',
    '#db_field_unaliased' => 'vid',
    '#key_component' => TRUE,
    '#csv_hidden' => TRUE,
  );
  $def['proteusquiz_exit_text'] = array(
    '#type' => 'int',
    '#title' => t('Exit Text'),
    '#db_field_unaliased' => 'exit_text',
    '#db_table' => 'proteus_quiz',
  );

  $def['proteus_quiz_objective_target'] = array(
    '#type' => 'array',
    '#title' => t('Traget Objectives'),
    '#xml_plural' => 'target_objectives',
    '#csv_plural' => 'target_objectives',
    '#xml_mapping' => 'target'
  );
  $def['proteus_quiz_objective_target']['nid'] = array(
    '#type' => 'int',
    '#title' => t('Node ID'),
    '#reference_entity' => $type,
    '#key_component' => TRUE,
  );
  $def['proteus_quiz_objective_target']['termid'] = array(
    '#type' => 'int',
    '#title' => t('Taxonomy term-id'),
    '#reference_entity' => 'term',
    '#reference_field' => array('tid'),
    '#key_component' => TRUE,
  );
  $def['proteus_quiz_objective_target']['targetlevel'] = array(
    '#type' => 'int',
    '#title' => t('Target Level')
  );

  $defs['proteusquiz'] = $def;

  return $defs;
}

/**
 * Implements hook_node_def_alter().
 */
function proteus_node_def_alter(&$def, $type) {
  if ($type == 'closedquestion') {
    $def['proteus_question_objective'] = array(
      '#type' => 'array',
      '#title' => t('Question objectives'),
      '#xml_plural' => 'proteus_question_objectives',
      '#csv_plural' => 'proteus_question_objectives',
      '#xml_mapping' => 'proteus_question_objective'
    );
    $def['proteus_question_objective']['termid'] = array(
      '#type' => 'int',
      '#title' => t('Taxonomy term-id'),
      '#reference_entity' => 'term',
      '#reference_field' => array('tid'),
      '#key_component' => TRUE,
    );
    $def['proteus_question_objective']['nid'] = array(
      '#type' => 'int',
      '#title' => t('Node ID'),
      '#reference_entity' => 'closedquestion',
      '#key_component' => TRUE,
    );
    $def['proteus_question_objective']['enterlevel'] = array(
      '#type' => 'int',
      '#title' => t('Enter Level')
    );
    $def['proteus_question_objective']['exitlevel'] = array(
      '#type' => 'int',
      '#title' => t('Exit Level')
    );
  }
}

/**
 * Implements hook_db_def_tables().
 */
function proteus_db_def_tables() {
  $tables = array();

  $tables['proteus_quiz'] = 'pz';
  $tables['proteus_quiz_objective_target'] = 'pzot';
  $tables['proteus_question_objective'] = 'pqo';

  return $tables;
}
